From - Wed Sep  1 11:21:29 1999
Received: by crusty.er.usgs.gov id OAA0000024555; Tue, 31 Aug 1999 14:29:50 -0400 (EDT)
Received: from quissett.er.usgs.gov
	by quissett.er.usgs.gov (AltaVista Mail V2.0/2.0 BL23 redirector)
	id 0000_0088_37cc_1e77_cb76
	for rsignell@nobska.er.usgs.gov;
	Tue, 31 Aug 1999 14:27:03 -0400
Received: from igsrsparc1.er.usgs.gov [130.11.48.89]
	by quissett.er.usgs.gov (AltaVista Mail V2.0/2.0 BL23 listener)
	id 0000_0088_37cc_1e70_cb73;
	Tue, 31 Aug 1999 14:26:56 -0400
Received: from mail.whoi.edu (mail.whoi.edu [128.128.76.8]) by igsrsparc1.er.usgs.GOV (EMAIL 1.2.1) with ESMTP id OAA13907 for <rsignell@usgs.gov>; Tue, 31 Aug 1999 14:33:13 -0400
Received: from bluedell ([128.128.30.15]) by mail.whoi.edu
          (Netscape Messaging Server 3.6)  with SMTP id AAA3020
          for <rsignell@usgs.gov>; Tue, 31 Aug 1999 14:33:10 -0400
Message-Id: <3.0.1.32.19990831143311.00935930@mail.whoi.edu>
X-Sender: rbeardsley@mail.whoi.edu
X-Mailer: Windows Eudora Pro Version 3.0.1 (32)
Date: Tue, 31 Aug 1999 14:33:11 -0400
To: "Richard P Signell,  Woods Hole, MA "<rsignell@nobska.er.usgs.gov>
From: rbeardsley@whoi.edu (Robert Beardsley)
Subject: ep.m
Mime-Version: 1.0
Content-Type: multipart/mixed; boundary="=====================_936138791==_"

--=====================_936138791==_
Content-Type: text/plain; charset="us-ascii"


--=====================_936138791==_
Content-Type: text/plain; charset="us-ascii"

function [E,P]=ep(rfd,Qlat)
% EP: computes evap and precip accumulation
% [E,P]=EP(rfd,Qlat) computes precipitation and evaporation 
% accumulation from rainfall rate rfd and latent heat 
% flux Qlat. Assumes hourly input. 
%
% INPUT:   rfd - precip rate  [mm/min]
%          Qlat - latent heat flux  [W/m^2]
%
% OUTPUT:  P - precip accumulation  [m] 
%          E - evaporation accumulation  [m]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 8/5/99: version 2.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% compute P
P=cumsum(rfd)./1000; % convert mm to m
dt=60; % for hourly data, dt = 60 min
P=P.*dt;

% compute E
Le=2.5e6; % heat of vaporization (W/m^2)
pw=1025; % density of seawater (kg/m^3) at 32 psu, 10 degC, 0 db
dt=3600; % seconds per hour
E=cumsum(Qlat).*dt./(Le.*pw);




--=====================_936138791==_
Content-Type: text/plain; charset="us-ascii"




robert c. beardsley             rbeardsley@whoi.edu
clark 343, ms#21                work: 508-289-2536
whoi                            home: 508-548-7148
woods hole, ma 02543            fax: 508-457-2181
--=====================_936138791==_--

